VPath

Struct VPath 

pub struct VPath<'a> { /* private fields */ }
A borrowed virtual path with an explicit separator policy.

Implementations

Source

impl<'a> VPath<'a>

pub const fn new(path: &'a str) -> Self

Creates a slash-delimited virtual path.

pub const fn with_separators(path: &'a str, separators: Separators) -> Self

Creates a virtual path with the given separator policy.

pub const fn as_str(self) -> &'a str

Returns the original, unnormalized path string.

pub const fn separators(self) -> Separators

Returns the separator policy.

pub fn components(self) -> Components<'a>

Iterates over lexical components.

pub fn is_absolute(self) -> bool

Returns whether the path begins with a recognized separator.

pub fn file_name(self) -> Option<&'a str>

Returns the last normal component.

pub fn split_file(self) -> Option<(Self, &'a str)>

Splits the path into its raw parent view and final normal component.

pub fn parent(self) -> Option<Self>

Returns the raw parent path when this path ends in a normal component.